database library

Classes

DatabaseMatch
Base class used for analysis
DatabaseRules
Database Rules annotation
Match
Database match statement
RuleDataSnapshot
A Rule Data Snapshot
RulesAuth
Request authentication context.
RulesString
Primitive type representing a string value.
RulesToken
a map of JWT token claims.

Enums

RulesIdentityProvider
Identity providers
RulesProvider
Rules provider
RulesSignInProvider
Sign in providers

Extensions

RulesStringExtension on String
Access to RulesString methods

Properties

auth → RulesAuth?
A variable containing the token payload if a client is authenticated, or null if the client isn't authenticated.
no setter
data → RuleDataSnapshot
A RuleDataSnapshot corresponding to the current data in Firebase Realtime Database at the location of the currently executing rule.
no setter
newData → RuleDataSnapshot
A RuleDataSnapshot corresponding to the data that will result if the write is allowed.
no setter
now → int
Contains the number of milliseconds since the Unix epoch according to the Firebase Realtime Database servers.
no setter
root → RuleDataSnapshot
A RuleDataSnapshot corresponding to the current data at the root of your Firebase Realtime Database.
no setter

Typedefs

ContextualCallback<T> = T Function(RulesString _)
A callback that provides information about the current rules context