Match class

Database match statement

Inheritance

Constructors

Match(String path, {ContextualCallback<bool>? read, ContextualCallback<bool>? write, ContextualCallback<bool>? validate, List<String>? indexOn, ContextualCallback<List<Match>>? matches})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexOn → List<String>?
Index on
final
matches → ContextualCallback<List<Match>>?
Matches
final
path → String
The path
final
read → ContextualCallback<bool>?
Read
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validate → ContextualCallback<bool>?
Validate
final
write → ContextualCallback<bool>?
Write
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited