RuleDataSnapshot class abstract

A Rule Data Snapshot

Constructors

RuleDataSnapshot()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

child(RulesString path) → RuleDataSnapshot
Gets a RuleDataSnapshot for the location at the specified relative path.
exists() → bool
Returns true if this RuleDataSnapshot contains any data.
getPriority() → dynamic
Gets the priority of the data in a RuleDataSnapshot.
hasChild(RulesString path) → bool
Returns true if the specified child exists.
hasChildren([List<RulesString> keys]) → bool
Checks for the existence of children.
isBoolean() → bool
Returns true if this RuleDataSnapshot contains a boolean value.
isNumber() → bool
Returns true if this RuleDataSnapshot contains a numeric value.
isString() → bool
Returns true if this RuleDataSnapshot contains a string value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parent() → RuleDataSnapshot
Gets a RuleDataSnapshot for the parent location.
toString() → String
A string representation of this object.
inherited
val<T>() → T
Gets the primitive value (string, number, boolean, or null) from this RuleDataSnapshot.

Operators

operator ==(Object other) → bool
The equality operator.
inherited