RulesAuth class abstract

Request authentication context.

Properties

hashCode → int
The hash code for this object.
no setterinherited
provider → RulesProvider
The authentication method used (e.g "password", "anonymous", "facebook", "github", "google", or "twitter").
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → RulesToken
a map of JWT token claims.
no setter
uid → RulesString
the UID of the requesting user.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited