RulesString class abstract

Primitive type representing a string value.

Constructors

RulesString()

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
Returns the length of the string.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginsWith(RulesString substring) → bool
Returns true if the string begins with the specified substring.
contains(RulesString substring) → bool
Returns true if the string contains the specified substring.
endsWith(RulesString substring) → bool
Returns true if the string ends with the specified substring.
matches(String regex) → bool
Returns true if the string matches the specified regular expression literal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(RulesString substring, RulesString replacement) → RulesString
Returns a copy of the string with all instances of a specified substring replaced with the specified replacement string.
toLowerCase() → RulesString
Returns a copy of the string converted to lower case.
toString() → String
A string representation of this object.
inherited
toUpperCase() → RulesString
Returns a copy of the string converted to upper case.

Operators

operator +(RulesString other) → RulesString
Add two strings together.
operator ==(Object other) → bool
The equality operator.
inherited