RulesToken class abstract

a map of JWT token claims.

Properties

email → RulesString
The email address associated with the account, if present
no setter
emailVerified → bool
true if the user has verified they have access to the email address.
no setter
hashCode → int
The hash code for this object.
no setterinherited
identities → Map<RulesIdentityProvider, List<RulesString>>
A map of all the identities that are associated with this user's account. The keys of the map can be any of the following: email, phone, google.com, facebook.com, github.com, twitter.com. The values of the map are lists of unique identifiers for each identitity provider associated with the account. For example, request.auth.token.firebase.identities["google.com"][0] contains the first Google user ID associated with the account.
no setter
name → RulesString
The user's display name, if set.
no setter
phoneNumber → RulesString
The phone number associated with the account, if present.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signInProvider → RulesSignInProvider
The sign-in provider used to obtain this token. Can be one of the following strings: custom, password, phone, anonymous, google.com, facebook.com, github.com, twitter.com. Translates to firebase.sign_in_provider
no setter
sub → RulesString
The user's Firebase UID. This is unique within a project.
no setter
tenant → RulesString
The tenantId associated with the account, if present. e.g. tenant2-m6tyz
no setter

Methods

customClaim<T>(String key) → T
Access to custom claims
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited