RulesBytes class abstract

Type representing a sequence of bytes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
size() → int
Returns the number of bytes in a Bytes sequence.
toBase64() → RulesString
Returns the Base64-encoded string corresponding to the provided Bytes sequence.
toHexString() → RulesString
Returns the hexadecimal-encoded string corresponding to the provided Bytes sequence.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited