RulesLatLng class abstract

Type representing a geopoint. Used in rules as latlng.

Constructors

RulesLatLng()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

distance(RulesLatLng other) → double
Calculate distance between two LatLng points in distance (meters).
latitude() → double
Get the latitude value in the range -90.0, 90.0.
longitude() → double
Get the longitude value in the range -180.0, 180.0.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited