RulesMap<K, V> class abstract

Map type, used for simple key-value mappings.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(K key) → bool
Check if key k exists in map x
diff(RulesMap<K, V> other) → MapDiff<K>
Return a rules.MapDiff representing the result of comparing the current Map to a comparison Map.
get(Object key, V defaultValue) → V
Returns the value associated with a given search key string.
keys() → RulesList<K>
Get the list of keys in the map.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
size() → int
Get the number of entries in the map.
toString() → String
A string representation of this object.
inherited
values() → RulesList<V>
Get the list of values in the map.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](K k) → V?
Index operator, get value at key name k