RulesQuery class abstract

Map of query properties, when present.

Properties

hashCode → int
The hash code for this object.
no setterinherited
limit → int
query limit clause.
no setter
offset → int
query offset clause.
no setter
orderBy → RulesString
query orderBy clause.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited