RulesRequest<T extends FirebaseResource> class abstract

The incoming request context.

Properties

auth → RulesAuth?
Request authentication context.
no setter
hashCode → int
The hash code for this object.
no setterinherited
method → RulesMethod
The request method.
no setter
path → RulesPath
Path of the affected resource.
no setter
query → RulesQuery
Map of query properties, when present.
no setter
resource → T
The new resource value, present on write requests only.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → RulesTimestamp
When the request was received by the service.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited