RulesString class abstract

Primitive type representing a string value.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

lower() → RulesString
Returns a lowercase version of the input string.
matches(RulesString regex) → bool
Performs a regular expression match on the whole string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
range(int i, int j) → RulesString
They can also be accessed using the range operator i:j. Note that parameter j, the upper bound in the range operator, is not inclusive.
replace(RulesString re, RulesString sub) → RulesString
Replaces all occurrences of substrings matching a regular expression with a user-supplied string.
size() → int
Returns the number of characters in the string.
split(RulesString re) → List<RulesString>
Splits a string according to a regular expression.
toString() → String
A string representation of this object.
inherited
toUtf8() → RulesBytes
Returns the UTF-8 byte encoding of a string.
trim() → RulesString
Returns a version of the string with leading and trailing spaces removed.
upper() → RulesString
Returns an uppercase version of the input string.

Operators

operator +(RulesString other) → RulesString
Strings can be concatenated using the + operator:
operator <(RulesString other) → bool
Strings can be lexicographically compared using the ==, !=, >, <, >= and <= operators.
operator <=(RulesString other) → bool
Strings can be lexicographically compared using the ==, !=, >, <, >= and <= operators.
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RulesString other) → bool
Strings can be lexicographically compared using the ==, !=, >, <, >= and <= operators.
operator >=(RulesString other) → bool
Strings can be lexicographically compared using the ==, !=, >, <, >= and <= operators.
operator [](int index) → RulesString
Sub-strings can be accessed using the index operator [].