RulesTimestamp class abstract

A timestamp in UTC with nanosecond accuracy.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

date() → RulesTimestamp
Timestamp value containing year, month, and day only.
day() → int
Get the day value of the timestamp.
dayOfWeek() → int
Get the day of the week as a value from 1 to 7.
dayOfYear() → int
Get the day of the year as a value from 1 to 366.
hours() → int
Get the hours value of the timestamp.
minutes() → int
Get the minutes value of the timestamp.
month() → int
Get the month value of the timestamp.
nanos() → int
Get the nanos value of the timestamp.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seconds() → int
Get the seconds value of the timestamp.
time() → RulesDuration
Get the duration value from the time portion of the timestamp.
toMillis() → int
Get the time in milliseconds since the epoch.
toString() → String
A string representation of this object.
inherited
year() → int
Get the year value of the timestamp.

Operators

operator +(RulesDuration duration) → RulesTimestamp
Add a duration to this timestamp
operator -(RulesDuration duration) → RulesTimestamp
Subtract a duration from this timestamp
operator ==(Object other) → bool
The equality operator.
inherited