StorageResource class abstract

The resource variable contains the metadata of a file being uploaded or the updated metadata for an existing file. This is related to the resource variable, which contains the current file metadata at the requested path, as opposed to the new metadata.

Constructors

StorageResource()

Properties

bucket → RulesString
A string containing the Google Cloud Storage bucket this file is stored in.
no setter
contentDisposition → RulesString
A string containing the content disposition of the file.
no setter
contentEncoding → RulesString
A string containing the content encoding of the file.
no setter
contentLanguage → RulesString
A string containing the content language of the file.
no setter
contentType → RulesString
The content type
no setter
crc32c → RulesString
A string containing the crc32c hash of the file.
no setter
etag → RulesString
A string containing the etag of the file.
no setter
generation → int
A int containing the Google Cloud Storage object generation of the file. Used for object versioning.
no setter
hashCode → int
The hash code for this object.
no setterinherited
md5Hash → RulesString
A string containing the MD5 hash of the file.
no setter
metadata → RulesMap<RulesString, RulesString>
A Map<String, String> containing additional developer provided metadata fields.
no setter
metageneration → int
A int containing the Google Cloud Storage object metageneration of the file. Used for object versioning.
no setter
name → RulesString
A string containing the full name of the file, including the path to the file.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
An int containing the file size in bytes.
no setter
timeCreated → RulesTimestamp
A timestamp representing when the file was created.
no setter
updated → RulesTimestamp
A timestamp representing when the file was last updated.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited